<?php
/**
 * Thor administration
 *
 * $Horde: thor/admin.php,v 1.24 2005/01/03 14:35:33 jan Exp $
 *
 * Copyright 2003-2005 Carlos Pedrinaci <cpedrinaci@yahoo.es>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('THOR_BASE', dirname(__FILE__));
require_once THOR_BASE . '/lib/base.php';
require_once 'Horde/UI/Tabs.php';
require_once 'Horde/UI/Pager.php';
require_once 'Horde/Variables.php';

if (!Auth::isAdmin('thor:admin')) {
    Horde::authenticationFailureRedirect();
}

// Input vars
$vars = &Variables::getDefaultVariables();
if (!$vars->exists('status')) {
    $vars->set('status', THOR_STATUS_REQUEST);
}

$projects_sortby = Util::getFormData('projects_sortby', $prefs->getValue('projects_sortby'));
$projects_sortdir = Util::getFormData('projects_sortdir', $prefs->getValue('projects_sortdir'));
$users_sortby = Util::getFormData('users_sortby', $prefs->getValue('users_sortby'));
$users_sortdir = Util::getFormData('users_sortdir', $prefs->getValue('users_sortdir'));
$projectID = $vars->get('project_id');
$actionID = $vars->get('actionID');
$status = $vars->get('status');
$confirm = $vars->get('confirm');
$show_confirmation = false;

/* Project Management Actions */
if (isset($projectID) && isset($actionID)) {
	// Get the project
    $project = &$thor->_projectsContainer->getProject($projectID);
    if (is_a($project, 'PEAR_Error')) {
        $notification->push(_("Unable to retrieve the project from the DB."), 'horde.error');
        header('Location: ' . Horde::applicationUrl('admin.php', true));
        exit;
    }

    switch ($actionID) {
    case DELETE_PROJECT:
        if ($project->data['project_status'] != THOR_STATUS_REQUEST) {

            if ($confirm == _("Yes")) {
                // The user has confirmed the action.
                $result = $thor->_projectsContainer->deleteProject($projectID);
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(_("Unable to remove the project from the DB."), 'horde.error');
                    header('Location: ' . Horde::applicationUrl('admin.php', true));
                    exit;
                } else {
                    $notification->push(_("Project removed."), 'horde.success');
                    header('Location: ' . Horde::applicationUrl('admin.php', true));
                    exit;
                }

            } elseif (!isset($confirm)) {
                // The user has not confirmed the action yet.
                $confirm_text = sprintf(_("Are you sure you want to delete the project '%s'?"), $project->getName());
                $show_confirmation = true;
            }
        }
        break;

    case BLOCK_PROJECT:
        if ($project->data['project_status'] != THOR_STATUS_REQUEST) {

            if ($confirm == _("Yes")) {
                // The user has confirmed the action.
                $project->set('project_status', THOR_STATUS_BLOCKED);
                $result = $thor->_projectsContainer->_projects->updateData($project);
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(_("Unable to block the project."), 'horde.error');
                    header('Location: ' . Horde::applicationUrl('admin.php', true));
                    exit;
                } else {
                    $notification->push(sprintf(_("Project '%s' blocked."), $project->getName()), 'horde.success');
                }

            } elseif (!isset($confirm)) {
                // The user has not confirmed the action yet.
                $confirm_text = sprintf(_("Are you sure you want to block the project '%s'?"), $project->getName());
                $show_confirmation = true;
            }
        }
        break;

    case UNBLOCK_PROJECT:
        if ($project->data['project_status'] != THOR_STATUS_REQUEST) {

            if ($confirm == _("Yes")) {
                // The user has confirmed the action.
                $project->set('project_status', THOR_STATUS_ACTIVE);
                $result = $thor->_projectsContainer->_projects->updateData($project);
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(_("Unable to unblock the project."), 'horde.error');
                    header('Location: ' . Horde::applicationUrl('admin.php', true));
                    exit;
                } else {
                    $notification->push(sprintf(_("Project '%s' unblocked."), $project->getName()), 'horde.success');
                }

            } elseif (!isset($confirm)) {
                // The user has not confirmed the action yet.
                $confirm_text = sprintf(_("Are you sure you want to unblock the project '%s'?"), $project->getName());
                $show_confirmation = true;
            }
        }
        break;

    case ACCEPT_PROJECT:
        if ($project->data['project_status'] == THOR_STATUS_REQUEST) {

            if ($confirm == _("Yes")) {
                /* Initialize the Project */
                $result = $project->initialize();
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(sprintf(_("Could not intialize the Project."), $project->getName()), 'horde.error');
                    header('Location: ' . Horde::applicationUrl('admin.php', true));
                    exit;
                }
                $notification->push(sprintf(_("Project '%s' created."), $project->getName()), 'horde.success');
                header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
                exit;

            } elseif (!isset($confirm)) {
                // The user has not confirmed the action yet.
                $confirm_text = sprintf(_("Are you sure you want to accept the project '%s'?"), $project->getName());
                $show_confirmation = true;
            }
        }
        break;

    case REFUSE_PROJECT:
        if ($project->data['project_status'] == THOR_STATUS_REQUEST) {

            if ($confirm == _("Yes")) {
                /* Initialize the Project */
                $result = $thor->_projectsContainer->deleteProject($projectID);
                if (is_a($result, 'PEAR_Error')) {
                    $notification->push(_("Could not refuse the project."), 'horde.error');
                    header('Location: ' . Horde::applicationUrl('admin.php', true));
                    exit;
                }
                $notification->push(sprintf(_("Project refused."), $project->getName()), 'horde.success');
                header('Location: ' . Horde::applicationUrl('admin.php', true));
                exit;

            } elseif (!isset($confirm)) {
                // The user has not confirmed the action yet.
                $confirm_text = sprintf(_("Are you sure you want to refuse the project '%s'?"), $project->getName());
                $show_confirmation = true;
            }
        }
        break;
    }
}

$adminurl = Horde::applicationUrl('admin.php');
$tabs = &new Horde_UI_Tabs('status', $vars);
$tabs->addTab(_("Active"), $adminurl, THOR_STATUS_ACTIVE);
$tabs->addTab(_("Blocked"), $adminurl, THOR_STATUS_BLOCKED);
$tabs->addTab(_("Requests"), $adminurl, THOR_STATUS_REQUEST);

switch ($status) {
case THOR_STATUS_ACTIVE:
    $listTitle = _("Active Projects");
    $numTitle = _("Projects");
    break;

case THOR_STATUS_BLOCKED:
    $listTitle = _("Blocked Projects");
    $numTitle = _("Projects");
    break;

case THOR_STATUS_REQUEST:
default:
    $listTitle = _("Projects Requests");
    $numTitle = _("Requests");
    break;
}

/* Page variables. */
$title = _("Thor Administration");
require THOR_TEMPLATES . '/common-header.inc';
require THOR_TEMPLATES . '/menu.inc';

/* Show the confirmation if required */
if ($show_confirmation) {
    require THOR_TEMPLATES . '/admin/confirmation.inc';
}

echo $tabs->render();

// Get the projects and sort them if necessary
$projectsList = &$thor->_projectsContainer->getProjects($status , DATATREE_ROOT, -1, false, true);
$orderedList = $thor->sortObjects($projectsList, $projects_sortby, $projects_sortdir);

$num_projects = count($orderedList);

$page = $vars->get('page');
$viewurl = Util::addParameter('admin.php', array(
        'sortby' => $projects_sortby,
        'sortdir' => $projects_sortdir,
        'status' => $status,
));

$maxpage = $prefs->getValue('projects_maxpage');
$perpage = $prefs->getValue('projects_perpage');

$min = $page * $perpage;
while ($min > $num_projects) {
    $page--;
    $min = $page * $perpage;
}
$projectsSlice = array_slice($orderedList, $min, $perpage);

$pager = &new Horde_UI_Pager('page', $vars, array('num' => $num_projects,
                                                  'url' => $viewurl,
                                                  'page_count' => $maxpage,
                                                  'perpage' => $perpage));

$leftHeaderText = $num_projects == 1 ? _("1 Project") : sprintf(_("%d Projects"), $num_projects);
$rightHeaderText = '';
$insertBreak = false;
require THOR_TEMPLATES . '/section-header.inc';
if ($num_projects) {
    require THOR_TEMPLATES . '/admin/project_headers.inc';
    // List the projects.
    foreach ($projectsSlice as $project) {
        require THOR_TEMPLATES . '/admin/project_summaries.inc';
    }
    require THOR_TEMPLATES . '/admin/footer.inc';
} else {
    require THOR_TEMPLATES . '/admin/empty.inc';
}
require THOR_TEMPLATES . '/admin/footer.inc';
// Show the pager
echo $pager->render();

// Choosen project
if (isset($projectID)) {
    $projectName = $thor->_projectsContainer->_projects->getName($projectID);
    if ( isset($projectsList[$projectName]) ) {
        $projectsList[$projectName]->showInformation(true);
        if ($projectsList[$projectName]->get('project_status') != THOR_STATUS_REQUEST) {
            $projectsList[$projectName]->showTeam($users_sortby, $users_sortdir);
        }
    }
}

require $registry->get('templates', 'horde') . '/common-footer.inc';
