<?php
/**
 * Creating or editting a project
 *
 * $Horde: thor/project.php,v 1.32 2005/01/03 14:35:33 jan Exp $
 *
 * Copyright 2003-2005 Carlos Pedrinaci <cpedrinaci@yahoo.es>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */

@define('THOR_BASE', dirname(__FILE__));
require_once THOR_BASE . '/lib/base.php';
require_once 'Horde/Variables.php';

$renderer = &new Horde_Form_Renderer();
$vars = &Variables::getDefaultVariables();

$projectID = $vars->get('project_id');

/* Page variables. */
$title = empty($projectID) ? _("New Project") : _("Edit Project");

if (empty($projectID)) {
    // New Project
    $form1 = &Horde_Form::singleton('ProjectForm', $vars);
    $currentForm = $vars->get('formname');
    if (isset($currentForm)) $form1->setSubmitted();
    if ($form1->isSubmitted() && $form1->validate($vars, true)) {

        $project_kind = $vars->get('project_kind');
        require_once THOR_LIBS . '/Project/' . $project_kind . '.php';
        $class = $project_kind . 'Form';

        $form2 = &Horde_Form::singleton($class, $vars);

        if ($form2->validate($vars)) {
            $form1->getInfo($vars, $info);
            $form2->getInfo($vars, $info);

            /* Check Requests Policy */
            if ($conf['requests']['handler'] == 'auto' && !$conf['requests']['params']['accept']) {
                /* The project is automatically refused */
                $notification->push(sprintf(_("Project Refused: %s"), $conf['requests']['params']['refuse_message']), 'horde.warning');
                header('Location: ' . Horde::applicationUrl('list.php', true));
            } else {
                /* Save the Project in any case */
                $id = $thor->_projectsContainer->saveProject($info);
                if (is_a($id, 'PEAR_Error')) {
                    $notification->push(_("Unable to store project's information."), 'horde.error');
                    header('Location: ' . Horde::applicationUrl('list.php', true));
                    exit;
                } else {
                    // Project stored
                    if ($conf['requests']['handler'] == 'auto' && $conf['requests']['params']['accept']) {
                        /* Initialize the Project */
                        $project = &$thor->_projectsContainer->getProject($id);
                        $result = $project->initialize();
                        if (is_a($result, 'PEAR_Error')) {
                            $thor->_projectsContainer->deleteProject($id);
                            $notification->push(_("Could not intialize the Project."), 'horde.error');
                            header('Location: ' . Horde::applicationUrl('list.php', true));
                            exit;
                        }
                        $notification->push(sprintf(_("Project Created: %s"), $conf['requests']['params']['accept_message']), 'horde.success');
                        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $id, true));
                        exit;
                    } else {
                        /* The Project must be accepted */
                        $notification->push(_("Project Requested."), 'horde.success');
                        header('Location: ' . Horde::applicationUrl('list.php', true));
                        exit;
                    }
                }
            }
        }

        require THOR_TEMPLATES . '/common-header.inc';
        require THOR_TEMPLATES . '/menu.inc';

        $form2->open($renderer, $vars, 'project.php', 'post');

        // Preserve previous form.
        $form1->preserve($vars);
        $renderer->beginInactive($form1->getTitle());
        $renderer->renderFormInactive($form1, $vars);
        $renderer->end();

        $renderer->beginActive($form2->getTitle());
        $renderer->renderFormActive($form2, $vars);
        $renderer->submit(_("Create Project"), _("Reset"));
        $renderer->end();
        $form2->close($renderer);
    } else {
        // Form1 not valid
        require THOR_TEMPLATES . '/common-header.inc';
        require THOR_TEMPLATES . '/menu.inc';
        $form1->setButtons(_("Continue"), _("Reset"));
        $form1->renderActive($renderer, $vars, 'project.php', 'post');
    }

} else {
    // We are editting a project
    $project = &$thor->_projectsContainer->getProject($projectID);
    if (is_a($project, 'PEAR_Error')) {
        $notification->push(_("Unable to retrieve the project"), 'horde.error');
        header('Location: ' . Horde::applicationUrl('list.php', true));
        exit;
    }

    if (!$project->isUserOfKind(Auth::getAuth(), USERS_ADMINS)) {
        // It isn't an admin
        $notification->push(sprintf(_("You can't access that page: You are not an administrator for that project.")), 'horde.warning');
        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
        exit;
    }

    if ($project->data['project_status'] == THOR_STATUS_BLOCKED) {
        // The project is blocked -> don't allow editting
        $notification->push(sprintf(_("You can't access that page: the project has been blocked.")), 'horde.warning');
        header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $projectID, true));
        exit;
    }

    $projectData = $project->toArray();
    $form1 = &Horde_Form::singleton('ProjectForm', $vars);
    $form2 = &Horde_Form::singleton($projectData['project_kind'] .'Form', $vars);

    if ($form2->validate($vars) && $form1->validate($vars, true)) {
        // All is ok Save data
        $form1->getInfo($vars, $info);
        $form2->getInfo($vars, $info);
        $result = $thor->_projectsContainer->saveProject($info);
        if (is_a($result, 'PEAR_Error')) {
            $notification->push(_("Unable to store project's information."), 'horde.error');
            header('Location: ' . Horde::applicationUrl('list.php', true));
            exit;
        } else {
            $notification->push(_("Project Modified."), 'horde.success');
            header('Location: ' . Horde::applicationUrl('view.php?project_id=' . $result, true));
            exit;
        }
    } else {
        if (!$form1->isSubmitted() && !$form2->isSubmitted()) {
            $vars = &new Variables($projectData);
        }
    }

    require THOR_TEMPLATES . '/common-header.inc';
    require THOR_TEMPLATES . '/menu.inc';
    $form2->open($renderer, $vars, 'project.php', 'post');

    // Print both forms
    $form1->preserve($vars);
    $renderer->beginActive($form1->getTitle());
    $renderer->renderFormActive($form1, $vars);
    $renderer->beginActive($form2->getTitle());
    $renderer->renderFormActive($form2, $vars);
    $renderer->submit(_("Save Changes"), _("Undo Changes"));
    $renderer->end();
    $form2->close($renderer);
}

require $registry->get('templates', 'horde') . '/common-footer.inc';